nvector.objects.FrameE — nvector 0.7.5 documentation

# nvector.objects.FrameE

class `FrameE`(a=None, f=None, name='WGS84', axes='e')

  Earth-fixed frame

  Parameters
    a: real scalar, default WGS-84 ellipsoid.

      Semi-major axis of the Earth ellipsoid given in [m].

    f: real scalar, default WGS-84 ellipsoid.

      Flattening [no unit] of the Earth ellipsoid. If f==0 then spherical Earth with radius a is used in stead of WGS-84.

    name: string

      defining the default ellipsoid.

    axes: ‘e’ or ‘E’

      defines axes orientation of E frame. Default is axes=’e’ which means that the orientation of the axis is such that: z-axis -> North Pole, x-axis -> Latitude=Longitude=0.

  See also

  `FrameN`, `FrameL`, `FrameB`

  Notes

  The frame is Earth-fixed (rotates and moves with the Earth) where the origin coincides with Earth’s centre (geometrical centre of ellipsoid model).

  `__init__`(self, a=None, f=None, name='WGS84', axes='e')

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `ECEFvector`(self, \*args, \*\*kwds) | Geographical position given as Cartesian position vector in frame E
  `GeoPoint`(self, \*args, \*\*kwds) | Geographical position given as latitude, longitude, depth in frame E.
  `Nvector`(self, \*args, \*\*kwds) | Geographical position given as n-vector and depth in frame E
  `__init__`(self[, a, f, name, axes]) | Initialize self.
  `direct`(self, lat_a, lon_a, azimuth, distance) | Returns position B computed from position A, distance and azimuth.
  `inverse`(self, lat_a, lon_a, lat_b, lon_b[, …]) | Returns ellipsoidal distance between positions as well as the direction.